@@ -19,9 +19,13 @@ class Patterns(CollectionApi):
     nullable_edits   = [ 'scale ']
 
     def add(self, name, slots:list=None, scale=None, octave_shift=None, rate=1, direction='forward', length=None):
+        if scale:
+            scale = self.api.scales.lookup(scale, require=True)
         params = locals()
         return self._generic_add(name, params)
 
     def edit(self, name, new_name:str=None, slots:list=None, scale=None, octave_shift=None, rate=None,  direction=None, length=None):
+        if scale:
+            scale = self.api.scales.lookup(scale, require=True)
         params = locals()
         return self._generic_edit(name, params)
\ No newline at end of file
