@@ -10,15 +10,13 @@
 
 import copy
 
-from .base import BaseObject
-
 NOTE_ON = 1
 NOTE_OFF = 0
 
 class Event(object):
 
 
-    __slots__ = [ 'type', 'note', 'time', 'on_event', 'from_context' ]
+    __slots__ = [ 'type', 'note', 'time', 'on_event', 'from_context', ]
 
     def __init__(self, type=None, note=None, time=None, on_event=None, from_context=None):
         self.type = type
